# Ansible role for Beakerlib tests

Put this role in your `tests.yml` playbook. The playbook will first install
beakerlib and restraint binaries on your localhost, then it will proceed to run
testing.  You can redefine the following variables in
`roles/standard-test-beakerlib/vars/main.yml`:

 * **tests**: A list of beakerlib test files
 * **fmf_filter**: An fmf filter to select tests based on test [metadata][1]
 * **artifacts**: An artifacts directory on localhost to store logs
 * **remote_artifacts**: The directory on the system under test where the logs
   are stored.  Note: if this variable is left undefined, it will default to
   `/tmp/artifacts`
 * **required_packages**: A list of prerequisite packages required by beakerlib
 tests. Please note that for Atomic Host, additional packages will be installed
 using the rpm-ostree command which is affecting the test subject (it's similar
 as rebuilding an rpm package to be tested) so this should be used with caution
 and only when necessary.
 * **repositories**: A list of dictionaries defining git repos with tests to be
   fetched. Available options are consistent with the ansible git module
   syntax:
     url ... repository url (required)
     dest ... destination directory (required)
     version ... desired branch (optional, defaults to master)
     fmf_filter ... fmf filter (optional, used for test selection)

Example usage:

```yaml
- hosts: localhost
  roles:
  - role: standard-test-beakerlib
    tags:
    - classic
    repositories:
    - repo: "https://src.fedoraproject.org/tests/shell.git"
      dest: "shell"
    tests:
    - shell/func
    - shell/login
    - shell/smoke
    required_packages:
    - expect
    - which
```

# Flexible Metadata Format support

## Filter required tests

Instead of manually listing all tests to be executed it is also possible to
provide an [fmf][1] filter in the following way:

```yaml
- hosts: localhost
  roles:
  - role: standard-test-beakerlib
    tags:
    - classic
    repositories:
    - repo: "https://src.fedoraproject.org/tests/shell.git"
      dest: "shell"
      fmf_filter: "tier: 1"
```

Filter can be used also if tests are stored directly in the git:

```yaml
- hosts: localhost
  roles:
  - role: standard-test-beakerlib
    tags:
    - classic
    fmf_filter: "tier: 1"
```

See the Fedora CI [metadata wiki][1] for more details and examples on test
metadata.

[1]: https://fedoraproject.org/wiki/CI/Metadata
